<?php

namespace Payroll\Piece\Http\Controllers\Api;

use App\Http\Controllers\Api\PublicController as BaseController;
use Payroll\Piece\Interfaces\PieceRepositoryInterface;
use Payroll\Piece\Repositories\Presenter\PieceItemTransformer;

/**
 * Pubic API controller class.
 */
class PiecePublicController extends BaseController
{
    /**
     * Constructor.
     *
     * @param type \Payroll\Piece\Interfaces\PieceRepositoryInterface $piece
     *
     * @return type
     */
    public function __construct(PieceRepositoryInterface $piece)
    {
        $this->repository = $piece;
        parent::__construct();
    }

    /**
     * Show piece's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $pieces = $this->repository
            ->setPresenter('\\Payroll\\Piece\\Repositories\\Presenter\\PieceListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->paginate();

        $pieces['code'] = 2000;
        return response()->json($pieces)
                ->setStatusCode(200, 'INDEX_SUCCESS');
    }

    /**
     * Show piece.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $piece = $this->repository
            ->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        if (!is_null($piece)) {
            $piece         = $this->itemPresenter($module, new PieceItemTransformer);
            $piece['code'] = 2001;
            return response()->json($piece)
                ->setStatusCode(200, 'SHOW_SUCCESS');
        } else {
            return response()->json([])
                ->setStatusCode(400, 'SHOW_ERROR');
        }

    }
}
