<?php

namespace Payroll\Piece\Http\Controllers;
use Litepie\Piece\Http\Requests\PieceRequest;
use Litepie\Piece\Models\Piece;

trait PieceWorkflow {
	
    /**
     * Workflow controller function for piece.
     *
     * @param Model   $piece
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(PieceRequest $request, Piece $piece, $step)
    {

        try {

            $piece->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('piece::piece.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/piece/piece/' . $piece->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/piece/piece/' . $piece->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for piece.
     *
     * @param Model   $piece
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
    */

    public function getWorkflow(Piece $piece, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $piece->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('piece::piece.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('piece::admin.piece.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('piece::admin.piece.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage(). '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('piece::admin.piece.message', $data)->render();

        }

    }
}