<?php

namespace Payroll\Piece\Policies;

use App\User;
use Payroll\Piece\Models\Piece;

class PiecePolicy
{

    /**
     * Determine if the given user can view the piece.
     *
     * @param User $user
     * @param Piece $piece
     *
     * @return bool
     */
    public function view(User $user, Piece $piece)
    {
        if ($user->canDo('piece.piece.view') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.view') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $piece->user_id;
    }

    /**
     * Determine if the given user can create a piece.
     *
     * @param User $user
     * @param Piece $piece
     *
     * @return bool
     */
    public function create(User $user)
    {
        return  $user->canDo('piece.piece.create');
    }

    /**
     * Determine if the given user can update the given piece.
     *
     * @param User $user
     * @param Piece $piece
     *
     * @return bool
     */
    public function update(User $user, Piece $piece)
    {
        if ($user->canDo('piece.piece.update') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.update') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $piece->user_id;
    }

    /**
     * Determine if the given user can delete the given piece.
     *
     * @param User $user
     * @param Piece $piece
     *
     * @return bool
     */
    public function destroy(User $user, Piece $piece)
    {
        if ($user->canDo('piece.piece.delete') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.delete') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $piece->user_id;
    }

    /**
     * Determine if the given user can verify the given piece.
     *
     * @param User $user
     * @param Piece $piece
     *
     * @return bool
     */
    public function verify(User $user, Piece $piece)
    {
        if ($user->canDo('piece.piece.verify') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('piece.piece.verify') 
        && $user->is('manager')
        && $piece->user->parent_id == $user->id) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given piece.
     *
     * @param User $user
     * @param Piece $piece
     *
     * @return bool
     */
    public function approve(User $user, Piece $piece)
    {
        if ($user->canDo('piece.piece.approve') && $user->is('admin')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperUser()) {
            return true;
        }
    }
}
