<?php

namespace Payroll\Piece\Workflow;

use Payroll\Piece\Models\Piece;
use Validator;

class PieceValidator
{

    /**
     * Determine if the given piece is valid for complete status.
     *
     * @param Piece $piece
     *
     * @return bool / Validator
     */
    public function complete(Piece $piece)
    {
        return Validator::make($piece->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given piece is valid for verify status.
     *
     * @param Piece $piece
     *
     * @return bool / Validator
     */
    public function verify(Piece $piece)
    {
        return Validator::make($piece->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given piece is valid for approve status.
     *
     * @param Piece $piece
     *
     * @return bool / Validator
     */
    public function approve(Piece $piece)
    {
        return Validator::make($piece->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given piece is valid for publish status.
     *
     * @param Piece $piece
     *
     * @return bool / Validator
     */
    public function publish(Piece $piece)
    {
        return Validator::make($piece->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given piece is valid for archive status.
     *
     * @param Piece $piece
     *
     * @return bool / Validator
     */
    public function archive(Piece $piece)
    {
        return Validator::make($piece->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given piece is valid for unpublish status.
     *
     * @param Piece $piece
     *
     * @return bool / Validator
     */
    public function unpublish(Piece $piece)
    {
        return Validator::make($piece->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
